parse_pwd

Function parse_pwd 

pub fn parse_pwd(bytes: &[u8]) -> Result<Vec<PwdSubstation>, Error>
Parse the substation coordinates out of .pwd bytes.

Errors

Error::FormatRead when the header is not the known display shape, the file has no substation identity table (bus only diagrams), or no unique drawing record group links to the identity rows.