parse_pwd_file

Function parse_pwd_file 

pub fn parse_pwd_file(path: impl AsRef<Path>) -> Result<PwdDisplay, Error>
Read and parse a .pwd display file.

Errors

Error::Io when the file cannot be read, or Error::FormatRead when the display bytes are not a supported PowerWorld .pwd shape.